==> haskell-type-errors-0.2.0.2-125.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-7Qd09D8Fl6HJAZ5yw1mjOD
key:                  type-errors-0.2.0.2-7Qd09D8Fl6HJAZ5yw1mjOD
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  80ba1b81221f6db7312794ba9fc931d1
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-7Qd09D8Fl6HJAZ5yw1mjOD
depends:
    base-4.18.2.1 first-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-0.2.0.2-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-5ovwO9wgzuv6OBxx9b6NBU
key:                  type-errors-0.2.0.2-5ovwO9wgzuv6OBxx9b6NBU
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  b3bc1afa913833524646e42c03f2bf67
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-5ovwO9wgzuv6OBxx9b6NBU
depends:
    base-4.18.2.1 first-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
